==> jbossas-plugin-1.2.2-sources.jar: com/xebialabs/deployit/plugin/jbossas/step/JbossasDeployApplicationStep.java <==
/*
 * Copyright (c) 2010 XebiaLabs B.V. All rights reserved.
 *
 * Your use of XebiaLabs Software and Documentation is subject to the Personal
 * License Agreement.
 *
 * http://www.xebialabs.com/deployit-personal-edition-license-agreement
 *
 * You are granted a personal license (i) to use the Software for your own
 * personal purposes which may be used in a production environment and/or (ii)
 * to use the Documentation to develop your own plugins to the Software.
 * "Documentation" means the how to's and instructions (instruction videos)
 * provided with the Software and/or available on the XebiaLabs website or other
 * websites as well as the provided API documentation, tutorial and access to
 * the source code of the XebiaLabs plugins. You agree not to (i) lease, rent
 * or sublicense the Software or Documentation to any third party, or otherwise
 * use it except as permitted in this agreement; (ii) reverse engineer,
 * decompile, disassemble, or otherwise attempt to determine source code or
 * protocols from the Software, and/or to  (iii) copy the Software or
 * Documentation (which includes the source code of the XebiaLabs plugins). You
 * shall not create or attempt to create any derivative works from the Software
 * except and only to the extent permitted by law. You will preserve XebiaLabs'
 * copyright and legal notices on the Software and Documentation. XebiaLabs
 * retains all rights not expressly granted to You in the Personal License
 * Agreement.
 */

package com.xebialabs.deployit.plugin.jbossas.step;

import com.xebialabs.deployit.StepExecutionContext;
import com.xebialabs.deployit.ci.Host;
import com.xebialabs.deployit.ci.artifact.Ear;
import com.xebialabs.deployit.ci.artifact.War;
import com.xebialabs.deployit.hostsession.HostFile;
import com.xebialabs.deployit.hostsession.HostFileUtils;
import com.xebialabs.deployit.hostsession.HostSession;
import com.xebialabs.deployit.hostsession.HostSessionFactory;
import com.xebialabs.deployit.plugin.jbossas.ci.JbossasServer;

/**
 * Deploys a {@link com.xebialabs.deployit.ci.artifact.Ear} or a {@link com.xebialabs.deployit.ci.artifact.War} to a
 * {@link com.xebialabs.deployit.plugin.jbossas.ci.JbossasServer}
 */
@SuppressWarnings("serial")
public class JbossasDeployApplicationStep extends JbossasDeploymentStepBase {

	public JbossasDeployApplicationStep(JbossasServer server, Ear ear) {
		super(server, ear);
		setDescription("Deploy EAR file " + ear + " to JBoss server " + server);
	}

	public JbossasDeployApplicationStep(JbossasServer server, War war) {
		super(server, war);
		setDescription("Deploy WAR file " + war + " to JBoss server " + server);
	}

	public boolean execute(StepExecutionContext ctx) {
		HostSession s = server.connectToAdminHost();
		try {
			HostSession ls = HostSessionFactory.getHostSession(Host.getLocalHost());
			try {
				HostFile sourceFile = ls.getFile(artifact.getLocation());

				String artifactTargetFileName = getArtifactTargetFileName();
				HostFile tmpDir = s.getFile(server.getTmpDirPath());
				HostFile targetTmpFile = tmpDir.getFile(artifactTargetFileName);
				ctx.logOutput("Copying application artifact to " + targetTmpFile.getPath() + " on " + server.getHost());
				HostFileUtils.copyFile(sourceFile, targetTmpFile);

				HostFile deployDir = s.getFile(server.getDeployDirPath());
				HostFile targetDeployFile = deployDir.getFile(artifactTargetFileName);
				ctx.logOutput("Moving application artifact from " + targetTmpFile.getPath() + " to " + targetDeployFile.getPath() + " on " + server.getHost());
				targetTmpFile.moveTo(targetDeployFile);

				ctx.logOutput("Done.");
				return true;
			} finally {
				ls.close();
			}
		} finally {
			s.close();
		}
	}

}

==> jbossas-plugin-1.3.2-sources.jar: com/xebialabs/deployit/plugin/jbossas/step/JbossasDeployApplicationStep.java <==
/*
 * Copyright (c) 2008-2010 XebiaLabs B.V. All rights reserved.
 *
 * Your use of XebiaLabs Software and Documentation is subject to the Personal
 * License Agreement.
 *
 * http://www.xebialabs.com/deployit-personal-edition-license-agreement
 *
 * You are granted a personal license (i) to use the Software for your own
 * personal purposes which may be used in a production environment and/or (ii)
 * to use the Documentation to develop your own plugins to the Software.
 * "Documentation" means the how to's and instructions (instruction videos)
 * provided with the Software and/or available on the XebiaLabs website or other
 * websites as well as the provided API documentation, tutorial and access to
 * the source code of the XebiaLabs plugins. You agree not to (i) lease, rent
 * or sublicense the Software or Documentation to any third party, or otherwise
 * use it except as permitted in this agreement; (ii) reverse engineer,
 * decompile, disassemble, or otherwise attempt to determine source code or
 * protocols from the Software, and/or to (iii) copy the Software or
 * Documentation (which includes the source code of the XebiaLabs plugins). You
 * shall not create or attempt to create any derivative works from the Software
 * except and only to the extent permitted by law. You will preserve XebiaLabs'
 * copyright and legal notices on the Software and Documentation. XebiaLabs
 * retains all rights not expressly granted to You in the Personal License
 * Agreement.
 */

package com.xebialabs.deployit.plugin.jbossas.step;

import com.xebialabs.deployit.StepExecutionContext;
import com.xebialabs.deployit.ci.Host;
import com.xebialabs.deployit.ci.artifact.Ear;
import com.xebialabs.deployit.ci.artifact.EjbJar;
import com.xebialabs.deployit.ci.artifact.War;
import com.xebialabs.deployit.hostsession.HostFile;
import com.xebialabs.deployit.hostsession.HostFileUtils;
import com.xebialabs.deployit.hostsession.HostSession;
import com.xebialabs.deployit.hostsession.HostSessionFactory;
import com.xebialabs.deployit.plugin.jbossas.ci.JbossasServer;

/**
 * Deploys a {@link com.xebialabs.deployit.ci.artifact.Ear} or a {@link com.xebialabs.deployit.ci.artifact.War} to a
 * {@link com.xebialabs.deployit.plugin.jbossas.ci.JbossasServer}
 */
@SuppressWarnings("serial")
public class JbossasDeployApplicationStep extends JbossasDeploymentStepBase {

	public JbossasDeployApplicationStep(JbossasServer server, Ear ear) {
		super(server, ear);
		setDescription("Deploy EAR " + ear + " to JBoss server " + server);
	}

	public JbossasDeployApplicationStep(JbossasServer server, War war) {
		super(server, war);
		setDescription("Deploy WAR " + war + " to JBoss server " + server);
	}

	public JbossasDeployApplicationStep(JbossasServer server, EjbJar ejbJar) {
		super(server, ejbJar);
		setDescription("Deploy EJB " + ejbJar + " to JBoss server " + server);
	}

	public boolean execute(StepExecutionContext ctx) {
		HostSession s = server.connectToAdminHost();
		try {
			HostSession ls = HostSessionFactory.getHostSession(Host.getLocalHost());
			try {
				HostFile sourceFile = ls.getFile(artifact.getLocation());

				String artifactTargetFileName = getArtifactTargetFileName();
				HostFile tmpDir = s.getFile(server.getTmpDirPath());
				HostFile targetTmpFile = tmpDir.getFile(artifactTargetFileName);
				ctx.logOutput("Copying application artifact to " + targetTmpFile.getPath() + " on " + server.getHost());
				HostFileUtils.copyFile(sourceFile, targetTmpFile);

				HostFile deployDir = s.getFile(server.getDeployDirPath());
				HostFile targetDeployFile = deployDir.getFile(artifactTargetFileName);
				ctx.logOutput("Moving application artifact from " + targetTmpFile.getPath() + " to " + targetDeployFile.getPath() + " on " + server.getHost());
				targetTmpFile.moveTo(targetDeployFile);

				ctx.logOutput("Done.");
				return true;
			} finally {
				ls.close();
			}
		} finally {
			s.close();
		}
	}

}
